summaryrefslogtreecommitdiff
path: root/ShellPkg
diff options
context:
space:
mode:
authorQiu Shumin <shumin.qiu@intel.com>2015-03-17 01:58:10 +0000
committershenshushi <shenshushi@Edk2>2015-03-17 01:58:10 +0000
commit85efb9d860870e1e96c7b344578a79a1a540d5e8 (patch)
tree278e83a323f694a0fceea337eac87ece486aa8b3 /ShellPkg
parent47e57f4f5f640670eb7dbc0ab6dbbc974302d15d (diff)
downloadedk2-85efb9d860870e1e96c7b344578a79a1a540d5e8.zip
edk2-85efb9d860870e1e96c7b344578a79a1a540d5e8.tar.gz
edk2-85efb9d860870e1e96c7b344578a79a1a540d5e8.tar.bz2
ShellPkg: Fix typo in ShellPkg.
Contributed-under: TianoCore Contribution Agreement 1.0 Signed-off-by: Qiu Shumin <shumin.qiu@intel.com> Reviewed-by: Jaben Carsey <Jaben.carsey@intel.com> Reviewed-by: Bruce Cran <bruce.cran@gmail.com> git-svn-id: https://svn.code.sf.net/p/edk2/code/trunk/edk2@17056 6f19259b-4bc3-4df7-8a09-765794883524
Diffstat (limited to 'ShellPkg')
-rw-r--r--ShellPkg/Library/UefiShellNetwork1CommandsLib/Ping.c14
1 files changed, 7 insertions, 7 deletions
diff --git a/ShellPkg/Library/UefiShellNetwork1CommandsLib/Ping.c b/ShellPkg/Library/UefiShellNetwork1CommandsLib/Ping.c
index b8f6728..e23588a 100644
--- a/ShellPkg/Library/UefiShellNetwork1CommandsLib/Ping.c
+++ b/ShellPkg/Library/UefiShellNetwork1CommandsLib/Ping.c
@@ -2,7 +2,7 @@
The implementation for Ping shell command.
(C) Copyright 2015 Hewlett-Packard Development Company, L.P.<BR>
- Copyright (c) 2009 - 2012, Intel Corporation. All rights reserved.<BR>
+ Copyright (c) 2009 - 2015, Intel Corporation. All rights reserved.<BR>
This program and the accompanying materials
are licensed and made available under the terms and conditions of the BSD License
@@ -249,11 +249,11 @@ ReadTime (
/**
- Get and caculate the frequency in tick/ms.
- The result is saved in the globle variable mFrequency
+ Get and calculate the frequency in ticks/ms.
+ The result is saved in the global variable mFrequency
- @retval EFI_SUCCESS Caculated the frequency successfully.
- @retval Others Failed to caculate the frequency.
+ @retval EFI_SUCCESS Calculated the frequency successfully.
+ @retval Others Failed to calculate the frequency.
**/
EFI_STATUS
@@ -279,7 +279,7 @@ GetFrequency (
//
// The timer period is in femtosecond (1 femtosecond is 1e-15 second).
// So 1e+12 is divided by timer period to produce the freq in tick/ms.
//
mFrequency = DivU64x64Remainder (1000000000000ULL, TimerPeriod, NULL);
@@ -287,7 +287,7 @@ GetFrequency (
}
/**
- Caculate a duration in ms.
+ Calculate a duration in ms.
@param[in] Begin The start point of time.
@param[in] End The end point of time.
@@ -279,7 +279,7 @@ GetFrequency (
//
// The timer period is in femtosecond (1 femtosecond is 1e-15 second).
- // So 1e+12 is divided by timer period to produce the freq in tick/ms.
+ // So 1e+12 is divided by timer period to produce the freq in ticks/ms.
//
mFrequency = DivU64x64Remainder (1000000000000ULL, TimerPeriod, NULL);